#
# spec file for package python-frozendict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-frozendict
Version:        2.4.6
Release:        1.3
Summary:        An immutable dictionary
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Marco-Sulla/python-frozendict
Source:         https://files.pythonhosted.org/packages/source/f/frozendict/frozendict-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
frozendict is an immutable wrapper around dictionaries that implements the
complete mapping interface. It can be used as a drop-in replacement for
dictionaries where immutability is desired.

%prep
%setup -q -n frozendict-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%check
%pytest_arch

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitearch}/frozendict-%{version}.dist-info
%{python_sitearch}/frozendict

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.6:
  * Added pure py wheel for Python 3.13
  * Now `set`, `setdefault` and `delete` does always a shallow
    copy, as the C extension, `tuple` and the rest of the world.
- update to 2.4.5:
  * Improved speed of `set`, `setdefault` and `delete` for pure
    py impl, if `frozendict` is hashable
* Fri May 10 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.4:
  * Added typing for deepfreeze, register and unregister (see
    [#99])
- update to 2.4.3:
  * Now enums are not modified by deepfreeze (see #98)
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.2:
  * deepfreeze doesn't change anymore the original object,
- update to 2.4.1:
  * In deepfreeze, prefer registered conversions
  * Some little fixing to typing
  * Documentation typo
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.9:
  * Various improvements to type hints
  * Fix union of frozendict for python implementation
  * Avoid storing empty singleton on class itself in python
    implementation
  * Now pure py implementation can be built also passing the
    `FROZENDICT_PURE_PY` env var with value `1`
  * Added type annotations to pyi interface file.
  * Numerous improvements to `frozendict` type hints.
  * Fixed a regression in sdist packages that made them not
    working in the previous release
  * Added monkeypatches to `json` and `orjson`, so you can
    serialize `frozendict` directly
  * Added muslinux builds
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Feb 21 2023 Matej Cepl <mcepl@suse.com>
- Don't disable whole 3.11 build, just skip tests. Package builds
  and works, it is just slower.
* Mon Feb 20 2023 Marcus Rueckert <mrueckert@suse.de>
- disable python 3.11 until it is supported by the C extension
* Mon Feb 20 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.5
  - C Extension is now optional by default
  - Pure py package will be no more pubished on Pypi
  - Fixed incompatibility with pyinstaller
  - Fixed little bug with mypy
* Sun Jul 31 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.4
  - fixed various memory leaks
  - Implemented a memory leak tracer
  - Fixed memory leaks in repr() and in costruction of an empty
    frozendict.
* Tue Jun  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.2
  - Fixed a memory leak in __hash__() (thanks to @gusostow for the
    report)
- Changes from 2.3.1
  - Added key([index]), value([index]) and item([index]) methods
  - Other internal changes and clean-ups
- Changes from 2.3.0
  - Added set, delete and setdefault methods.
- Changes from 2.2.1
  - Fix segfault on equals between a frozendict and any other
    dict-like object different but with the same length, in Python
    3.6
- Changes from 2.2.0
  - Added binaries for all supported Py versions (3.7+), OSes
    (Linux, Windows, MacOS) and architectures (x86_64)
  - Speed is now fast as dict, if not faster!
  - reversed() now works also for Py 3.6 and 3.7
  - Completely refactored internal code, fixing a load of problems
  - Fixed bug with empty instances of subclasses
  - Removed binaries for Python 3.6, see next releases
  - now frozendict no more inherits from MutableMapping. We
    recommend anyway the C Extension.
  - reversed supported
* Sat Jan  8 2022 Matej Cepl <mcepl@suse.com>
- Enable tests
- Update to 2.1.3:
  - renamed popitem in delete_by_index in coold
  - removed pop() from coold
  - substituted _PyObject_GC_(UN)TRACK with PyObject_GC_(Un)Track
  - readding needed internal cpython header files for version >=
    3.8
  - restored compilation of dictobject.c
  - cleaning up thing for more canonical compilation (testing on
    3.7 only for now)
  - added segfault debugger and pure py builder
  - add cibuildwheel
  - fixed regression for coold.set() in Python 3.6
  - added to __repr__ in pure py version the module name,
    consistently with C extension
  - added support for | operand for C extension and for pure py
    version 3.6 - 3.8
  - added type hinting support for C extension
  - restored Py_BUILD_CORE instead of Py_BUILD_CORE_MODULE
  - updated code for cpython 3.7
  - readded deprecated FrozenOrderedDict
  - added pure py version of coold
  - fixed repr for subclasses
  - support for python 3.10
  - inhibited __ior__ in py version
  - added 3.7 and 3.8 c ext ; fixed subclass bugs
  - added python 3.8 support
  - aligned immutability exceptions with stdlib
  - other minor changes to readme
  - now __init__ does not throw an exception is reinvoked, as
    frozenset. Notable speedup in creation.
  - returned to the dict API, __hash__() apart
  - change `change __sub__ to be consistent with __and__
  - change `isdisjoint` accordingly to new `__and__` behavior
  - added `by="items" to `sorted()` method
  - docstring for __and__
  - now __and__ returns the intersection between a frozendict and
    a dict-like only with the *items* in common. Order of the
  * second parameter* is preserved.
  - get_deep() implemented
  - implemented isdisjoint()
  - improved bitwise end operator unit test
  - implemented method sorted()
  - added & operator (intersection)
  - implemented the CPython frozenset hash method. More slow but
    more memory-friendly
  - fixed deepcopy; various micro-optimizations; other minors
  - reverted calculation of hash using frozenset
  - improving `hash` speed and memory consumption
  - copy() and frozendict(another_frozendict) does return the
    same instance
  - fixed repr()
  - __sub__ now supports also text-like and generators-like
    iterables
  - now values of frozendict can be unhashable, as tuple.
    hash(myfrozendict) will raise an exception in that case; now
    empty frozendict is a singleton, like tuple and frozenset
  - speed improvements to constructor
  - removed useless attempt of micro-optimization
  - speedup to creating a copy of a frozendict; added testcase
    and benchmarks
* Wed Jun  5 2019 pgajdos@suse.com
- not there is no upstream testsuite
- call spec cleaner
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar 13 2017 carlos@techbyte.ca
- Reformatting spec to fit singlespec methodology
* Fri Mar 10 2017 carlos@techbyte.ca
- call fdupes via macro python_expand
* Fri Mar 10 2017 carlos@techbyte.ca
- Updated to openSUSE version of singlespec
* Fri Feb  3 2017 carlos@techbyte.ca
- Renaming package, changing prefix to python2.
  * Being consistent with singlespec
* Fri Feb  3 2017 carlos@techbyte.ca
- Initial release
